==> assert-is-boolean-array-0.0.7.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isBooleanArray

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test if a value is an array-like object of booleans.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-boolean-array
```

</section>

<section class="usage">

## Usage

```javascript
var isBooleanArray = require( '@stdlib/assert-is-boolean-array' );
```

#### isBooleanArray( value )

Tests if a `value` is an array-like object of `booleans`.

```javascript
var bool = isBooleanArray( [ true, false, false, true ] );
// returns true
```

#### isBooleanArray.primitives( value )

Tests if a `value` is an array-like object containing **only** `boolean` primitives.

<!-- eslint-disable no-new-wrappers -->

```javascript
var bool = isBooleanArray.primitives( [ true, false ] );
// returns true

bool = isBooleanArray.primitives( [ false, new Boolean( true ) ] );
// returns false
```

#### isBooleanArray.objects( value )

Tests if a `value` is an array-like object containing **only** `Boolean` objects.

<!-- eslint-disable no-new-wrappers, max-len -->

```javascript
var bool = isBooleanArray.objects( [ new Boolean( false ), new Boolean( true ) ] );
// returns true

bool = isBooleanArray.objects( [ new Boolean( false ), true ] );
// returns false
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint-disable no-new-wrappers -->

<!-- eslint no-undef: "error" -->

```javascript
var isBooleanArray = require( '@stdlib/assert-is-boolean-array' );

var bool = isBooleanArray( [ true, false ] );
// returns true

bool = isBooleanArray( [ true, new Boolean( false ) ] );
// returns true

bool = isBooleanArray( [ true, 'false' ] );
// returns false

bool = isBooleanArray( [] );
// returns false

bool = isBooleanArray( null );
// returns false
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-boolean-array.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-boolean-array

[test-image]: https://github.com/stdlib-js/assert-is-boolean-array/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-is-boolean-array/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-boolean-array/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-boolean-array?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-boolean-array.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-boolean-array/main

-->

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-boolean-array/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-boolean-array/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-boolean-array/tree/esm

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-boolean-array/main/LICENSE

</section>

<!-- /.links -->

==> assert-is-boolean-array-0.0.8.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isBooleanArray

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Test if a value is an array-like object of booleans.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-is-boolean-array
```

</section>

<section class="usage">

## Usage

```javascript
var isBooleanArray = require( '@stdlib/assert-is-boolean-array' );
```

#### isBooleanArray( value )

Tests if a `value` is an array-like object of `booleans`.

```javascript
var bool = isBooleanArray( [ true, false, false, true ] );
// returns true
```

#### isBooleanArray.primitives( value )

Tests if a `value` is an array-like object containing **only** `boolean` primitives.

<!-- eslint-disable no-new-wrappers -->

```javascript
var bool = isBooleanArray.primitives( [ true, false ] );
// returns true

bool = isBooleanArray.primitives( [ false, new Boolean( true ) ] );
// returns false
```

#### isBooleanArray.objects( value )

Tests if a `value` is an array-like object containing **only** `Boolean` objects.

<!-- eslint-disable no-new-wrappers, max-len -->

```javascript
var bool = isBooleanArray.objects( [ new Boolean( false ), new Boolean( true ) ] );
// returns true

bool = isBooleanArray.objects( [ new Boolean( false ), true ] );
// returns false
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint-disable no-new-wrappers -->

<!-- eslint no-undef: "error" -->

```javascript
var isBooleanArray = require( '@stdlib/assert-is-boolean-array' );

var bool = isBooleanArray( [ true, false ] );
// returns true

bool = isBooleanArray( [ true, new Boolean( false ) ] );
// returns true

bool = isBooleanArray( [ true, 'false' ] );
// returns false

bool = isBooleanArray( [] );
// returns false

bool = isBooleanArray( null );
// returns false
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-is-boolean-array.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-is-boolean-array

[test-image]: https://github.com/stdlib-js/assert-is-boolean-array/actions/workflows/test.yml/badge.svg?branch=v0.0.8
[test-url]: https://github.com/stdlib-js/assert-is-boolean-array/actions/workflows/test.yml?query=branch:v0.0.8

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-is-boolean-array/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-is-boolean-array?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-is-boolean-array.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-is-boolean-array/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-is-boolean-array/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-is-boolean-array/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-is-boolean-array/tree/esm
[branches-url]: https://github.com/stdlib-js/assert-is-boolean-array/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-is-boolean-array/main/LICENSE

</section>

<!-- /.links -->
